@@ -55,8 +55,30 @@ import subprocess
 from ._utils import TERM_WIDTH, int_cast_or_len, fext, _str, \
     check_output, tqdm, TqdmStream, print_unicode, Str, string_types, \
     merge_stats
-from ._version import __version__  # NOQA
 
+
+def get_version_dist(name=__name__):
+    from pkg_resources import DistributionNotFound, get_distribution
+
+    try:
+        return get_distribution(name).version
+    except DistributionNotFound:
+        return "UNKNOWN"
+
+
+try:
+    from setuptools_scm import get_version
+except ImportError:
+    ROOT = path.abspath(path.dirname(path.dirname(__file__)))
+    if path.exists(path.join(ROOT, ".git")):
+        __version__ = "UNKNOWN - please install setuptools_scm"
+    else:
+        __version__ = get_version_dist()
+else:
+    try:
+        __version__ = get_version(root="..", relative_to=__file__)
+    except LookupError:
+        __version__ = get_version_dist()
 __author__ = "Casper da Costa-Luis <casper@caspersci.uk.to>"
 __date__ = "2016-2020"
 __licence__ = "[MPLv2.0](https://mozilla.org/MPL/2.0/)"
@@ -206,7 +228,7 @@ def _get_auth_stats(
   log.log(logging.NOTSET, "files:\n" + '\n'.join(file_list))
 
   auth_stats = {}
-  for fname in tqdm(file_list, desc=gitdir if prefix_gitdir else "Blame",
+  for fname in tqdm(file_list, desc=gitdir if prefix_gitdir else "Processing",
                     disable=silent_progress, unit="file"):
     git_blame_cmd = git_cmd + ["blame", "--line-porcelain", branch, fname] + \
         since
@@ -371,11 +393,15 @@ def run(args):
       args.sort, args.bytype, args.format, args.cost))
 
 
+def get_main_parser():
+  from argopt import argopt
+  return argopt(__doc__ + '\n' + __copyright__, version=__version__)
+
+
 def main(args=None):
   """args  : list [default: sys.argv[1:]]"""
-  from argopt import argopt
-  args = argopt(__doc__ + '\n' + __copyright__,
-                version=__version__).parse_args(args=args)
+  parser = get_main_parser()
+  args = parser.parse_args(args=args)
   logging.basicConfig(
       level=getattr(logging, args.log, logging.INFO),
       stream=TqdmStream,
